import { onMounted, onUnmounted } from 'nativescript-vue';
import { unrefView } from '../unrefView';
/**
 * Register using view.on on mounted, and view.off automatically on unmounted.
 *
 *
 * @param target
 * @param events
 */
export function useEventListener(target, events) {
    const el = target;
    const fireEvent = (onEvent) => (args) => onEvent(args);
    onMounted(() => {
        Object.keys(events).forEach((event) => {
            unrefView(el)?.on(event, fireEvent(events[event]));
        });
    });
    onUnmounted(() => {
        cleanup();
    });
    function cleanup() {
        Object.keys(events).forEach((event) => {
            unrefView(el)?.off(event, fireEvent(events[event]));
        });
    }
    return {
        cleanup,
    };
}
//# sourceMappingURL=index.js.map