import { ref, readonly, onUnmounted } from 'nativescript-vue';
import { CoreTypes } from '@nativescript/core';
import { Orientation } from '@nativescript-use/nativescript-orientation';
/**
 * Reactive screen orientation and utilities to manage the orientation.
 *
 * @param target
 * @param options
 */
export function useScreenOrientation(options) {
    const orientationCore = new Orientation();
    const orientation = ref(orientationCore.getOrientation());
    let tryCount = 0;
    function tryOrientation() {
        if (orientation.value === CoreTypes.DeviceOrientation.unknown) {
            if (tryCount < 4) {
                setTimeout(() => {
                    tryCount++;
                    tryOrientation();
                }, 100);
            }
        }
        else {
            orientation.value = orientationCore.getOrientation();
            if (options?.onChange)
                options.onChange(orientation.value);
        }
    }
    if (orientation.value === CoreTypes.DeviceOrientation.unknown)
        tryOrientation();
    orientationCore.onChangedOrientation((value) => {
        orientation.value = value.newValue;
        if (options?.onChange)
            options.onChange(orientation.value);
    });
    onUnmounted(() => {
        orientationCore.offChangedOrientation();
    });
    return {
        orientation: readonly(orientation),
        setOrientation: orientationCore.setOrientation,
        enableRotation: orientationCore.enableRotation,
        disableRotation: orientationCore.disableRotation,
    };
}
//# sourceMappingURL=index.js.map